@@ -1,10 +1,10 @@
 from .induction import Induction
 from .induction_case import InductionCase
 from .simple_statements import SimpleStatement
-from .such_that import SuchThat
 from .have import Have
 from .proof_structure import ProofStructure
 from .statement import Statement
+from ...propositions.such_that import SuchThat
 from ...propositions.multiple_propositions import MultiplePropositions
 from ...utils.exceptions import MatchingError, TranslationError
 
